@@ -37,10 +37,10 @@ import tempfile
 import threading
 import signal
 import sys
-import robotide.utils as utils
 from Queue import Empty, Queue
-from robot.output.loggerhelper import LEVELS
-from robot.utils.encoding import SYSTEM_ENCODING
+
+from robotide import utils
+from robotide.robotapi import LOG_LEVELS
 from robotide.context import IS_WINDOWS
 from robotide.contrib.testrunner import TestRunnerAgent
 from robotide.controller.testexecutionresults import TestExecutionResults
@@ -171,7 +171,7 @@ class TestRunner(object):
         self._process = Process(cwd)
         self._process.run_command(command)
 
-    def get_command(self, profile, pythonpath, monitor_width, names_to_run):
+    def get_command(self, profile, pythonpath, console_width, names_to_run):
         '''Return the command (as a list) used to run the test'''
         command = profile.get_command_prefix()[:]
         argfile = os.path.join(self._output_dir, "argfile.txt")
@@ -179,12 +179,12 @@ class TestRunner(object):
         command.extend(["--listener", self._get_listener_to_cmd()])
         command.append(self._get_suite_source_for_command())
         self._write_argfile(argfile, self._create_standard_args(
-            command, profile, pythonpath, monitor_width, names_to_run))
+            command, profile, pythonpath, console_width, names_to_run))
         return command
 
     @staticmethod
     def get_message_log_level(command):
-        min_log_level_number = LEVELS['INFO']
+        min_log_level_number = LOG_LEVELS['INFO']
         if '-L' in command:
             switch = '-L'
         elif '--loglevel' in command:
@@ -195,7 +195,7 @@ class TestRunner(object):
         if len(command) == i:
             return
         level = command[i+1].upper().split(':')[0]
-        return LEVELS.get(level, min_log_level_number)
+        return LOG_LEVELS.get(level, min_log_level_number)
 
     def _get_listener_to_cmd(self):
         path = os.path.abspath(TestRunnerAgent.__file__)
@@ -211,14 +211,16 @@ class TestRunner(object):
         return os.path.abspath(self._project.suite.source)
 
     def _create_standard_args(
-            self, command, profile, pythonpath, monitor_width, names_to_run):
+            self, command, profile, pythonpath, console_width, names_to_run):
         standard_args = []
         standard_args.extend(profile.get_custom_args())
         self._add_tmp_outputdir_if_not_given_by_user(command, standard_args)
         self._add_pythonpath_if_in_settings_and_not_given_by_user(
             command, standard_args, pythonpath)
-        standard_args.extend(["--monitorcolors", "off"])
-        standard_args.extend(["--monitorwidth", monitor_width])
+        # Have to use short options, because of long option was changed in
+        # RF 2.8 -> 2.9, and we don't necessarily know the installed version.
+        standard_args.extend(["-C", "off"]) # --consolecolor
+        standard_args.extend(["-W", console_width]) # --consolewidth
         for suite, test in names_to_run:
             standard_args += ['--suite', suite, '--test', test]
         return standard_args
@@ -275,7 +277,7 @@ class Process(object):
                         stdout=subprocess.PIPE,
                         stderr=subprocess.PIPE,
                         stdin=subprocess.PIPE,
-                        cwd=self._cwd.encode(SYSTEM_ENCODING))
+                        cwd=self._cwd.encode(utils.SYSTEM_ENCODING))
         if IS_WINDOWS:
             startupinfo = subprocess.STARTUPINFO()
             try:
@@ -287,7 +289,7 @@ class Process(object):
         else:
             subprocess_args['preexec_fn'] = os.setsid
             subprocess_args['shell'] = True
-        self._process = subprocess.Popen(command.encode(SYSTEM_ENCODING),
+        self._process = subprocess.Popen(command.encode(utils.SYSTEM_ENCODING),
                                          **subprocess_args)
         self._process.stdin.close()
         self._output_stream = StreamReaderThread(self._process.stdout)
