@@ -30,7 +30,7 @@ from robotide.utils.highlightmatcher import highlight_matcher
 from .formatters import ListToStringFormatter
 from .gridcolorizer import ColorizationSettings
 from .editordialogs import EditorDialog, DocumentationDialog, MetadataDialog,\
-    ScalarVariableDialog, ListVariableDialog, LibraryDialog,\
+    ScalarVariableDialog, ListVariableDialog, DictionaryVariableDialog, LibraryDialog,\
     ResourceDialog, VariablesDialog
 from .listeditor import ListEditor
 from .popupwindow import HtmlPopupWindow
@@ -303,15 +303,10 @@ class TagsEditor(SettingEditor):
     def __init__(self, parent, controller, plugin, tree):
         SettingEditor.__init__(self, parent, controller, plugin, tree)
         self.plugin.subscribe(self._saving, RideSaving)
-        self.Bind(wx.EVT_SIZE, self.OnSize)
 
     def _saving(self, message):
         self._tags_display.saving()
 
-    def OnSize(self, event):
-        self.SetSizeHints(-1, max(self._tags_display.get_height(), 25))
-        event.Skip()
-
     def _value_display_control(self):
         self._tags_display = TagsDisplay(self, self._controller)
         self._tags_display.Bind(wx.EVT_LEFT_UP, self.OnLeftUp)
@@ -361,7 +356,7 @@ class _AbstractListEditor(ListEditor):
 
 class VariablesListEditor(_AbstractListEditor):
     _titles = ['Variable', 'Value', 'Comment']
-    _buttons = ['Add Scalar', 'Add List']
+    _buttons = ['Add Scalar', 'Add List', 'Add Dict']
 
     def __init__(self, parent, tree, controller):
         PUBLISHER.subscribe(
@@ -391,15 +386,19 @@ class VariablesListEditor(_AbstractListEditor):
         self._list.SetFocus()
 
     def OnAddScalar(self, event):
-        dlg = ScalarVariableDialog(self._controller)
-        if dlg.ShowModal() == wx.ID_OK:
-            ctrl = self._controller.add_variable(*dlg.get_value())
-            ctrl.set_comment(dlg.get_comment())
-            self.update_data()
-        dlg.Destroy()
+        self._show_dialog(
+            ScalarVariableDialog(self._controller))
 
     def OnAddList(self, event):
-        dlg = ListVariableDialog(self._controller, plugin=self.Parent.plugin)
+        self._show_dialog(
+            ListVariableDialog(self._controller, plugin=self.Parent.plugin))
+
+    def OnAddDict(self, event):
+        self._show_dialog(
+            DictionaryVariableDialog(self._controller,
+                                     plugin=self.Parent.plugin))
+
+    def _show_dialog(self, dlg):
         if dlg.ShowModal() == wx.ID_OK:
             ctrl = self._controller.add_variable(*dlg.get_value())
             ctrl.set_comment(dlg.get_comment())
@@ -411,14 +410,20 @@ class VariablesListEditor(_AbstractListEditor):
         self._open_var_dialog(var)
 
     def _open_variable_dialog(self, message):
-        self._open_var_dialog(message.controller)
+        # Prevent opening a dialog if self hase been destroyed
+        if self:
+            self._open_var_dialog(message.controller)
 
     def _open_var_dialog(self, var):
-        if var.name.startswith('${'):
+        var_name = var.name.lower()
+        if var_name.startswith('${'):
             dlg = ScalarVariableDialog(self._controller, item=var)
-        else:
+        elif var_name.startswith('@{'):
             dlg = ListVariableDialog(self._controller, item=var,
                                      plugin=self.Parent.plugin)
+        elif var_name.startswith('&{'):
+            dlg = DictionaryVariableDialog(self._controller, item=var,
+                                           plugin=self.Parent.plugin)
         if dlg.ShowModal() == wx.ID_OK:
             name, value = dlg.get_value()
             var.execute(UpdateVariable(name, value, dlg.get_comment()))
