@@ -1,4 +1,4 @@
-#  Copyright 2008-2012 Nokia Siemens Networks Oyj
+#  Copyright 2008-2015 Nokia Solutions and Networks
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -15,21 +15,21 @@
 import os
 import copy
 
-from robot.errors import DataError
-from robot.variables import is_var
-from robot.output import LOGGER
-from robot import utils
-from robot.writer import DataFileWriter
+from robotide.lib.robot.errors import DataError
+from robotide.lib.robot.variables import is_var
+from robotide.lib.robot.output import LOGGER
+from robotide.lib.robot.writer import DataFileWriter
+from robotide.lib.robot.utils import abspath, is_string, normalize, NormalizedDict
 
 from .comments import Comment
 from .populators import FromFilePopulator, FromDirectoryPopulator
-from .settings import (Documentation, Fixture, Timeout, Tags, Metadata, Library,
-    Resource, Variables, Arguments, Return, Template, MetadataList, ImportList)
+from .settings import (Documentation, Fixture, Timeout, Tags, Metadata,
+                       Library, Resource, Variables, Arguments, Return,
+                       Template, MetadataList, ImportList)
 
 
-def TestData(parent=None, source=None, include_suites=[],
+def TestData(parent=None, source=None, include_suites=None,
              warn_on_skipped=False):
-    # TODO: can we change the order of parent and source?? source seems mandatory
     """Parses a file or directory to a corresponding model object.
 
     :param parent: (optional) parent to be used in creation of the model object.
@@ -51,9 +51,9 @@ class _TestData(object):
 
     def __init__(self, parent=None, source=None):
         self.parent = parent
-        self.source = utils.abspath(source) if source else None
+        self.source = abspath(source) if source else None
         self.children = []
-        self._tables = utils.NormalizedDict(self._get_tables())
+        self._tables = NormalizedDict(self._get_tables())
 
     def _get_tables(self):
         for names, table in [(self._setting_table_names, self.setting_table),
@@ -96,11 +96,10 @@ class _TestData(object):
     def imports(self):
         return self.setting_table.imports
 
-    def report_invalid_syntax(self, table, message, level='ERROR'):
+    def report_invalid_syntax(self, message, level='ERROR'):
         initfile = getattr(self, 'initfile', None)
         path = os.path.join(self.source, initfile) if initfile else self.source
-        LOGGER.write("Error in file '%s' in table '%s': %s"
-                     % (path, table, message), level)
+        LOGGER.write("Error in file '%s': %s" % (path, message), level)
 
     def save(self, **options):
         """Writes this datafile to disk.
@@ -115,7 +114,11 @@ class _TestData(object):
 
 
 class TestCaseFile(_TestData):
-    """The parsed test case file object."""
+    """The parsed test case file object.
+
+    :param parent: parent object to be used in creation of the model object.
+    :param source: path where test data is read from.
+    """
 
     def __init__(self, parent=None, source=None):
         self.directory = os.path.dirname(source) if source else None
@@ -147,7 +150,10 @@ class TestCaseFile(_TestData):
 
 
 class ResourceFile(_TestData):
-    """The parsed resource file object."""
+    """The parsed resource file object.
+
+    :param source: path where resource file is read from.
+    """
 
     def __init__(self, source=None):
         self.directory = os.path.dirname(source) if source else None
@@ -184,6 +190,9 @@ class TestDataDirectory(_TestData):
     """The parsed test data directory object. Contains hiearchical structure
     of other :py:class:`.TestDataDirectory` and :py:class:`.TestCaseFile`
     objects.
+
+    :param parent: parent object to be used in creation of the model object.
+    :param source: path where test data is read from.
     """
 
     def __init__(self, parent=None, source=None):
@@ -195,7 +204,7 @@ class TestDataDirectory(_TestData):
         self.keyword_table = KeywordTable(self)
         _TestData.__init__(self, parent, source)
 
-    def populate(self, include_suites=[], warn_on_skipped=False, recurse=True):
+    def populate(self, include_suites=None, warn_on_skipped=False, recurse=True):
         FromDirectoryPopulator().populate(self.source, self, include_suites,
                                           warn_on_skipped, recurse)
         self.children = [ch for ch in self.children if ch.has_tests()]
@@ -256,7 +265,7 @@ class _Table(object):
         return self.parent.directory
 
     def report_invalid_syntax(self, message, level='ERROR'):
-        self.parent.report_invalid_syntax(self.name, message, level)
+        self.parent.report_invalid_syntax(message, level)
 
     def __nonzero__(self):
         return bool(self._header or len(self))
@@ -277,7 +286,7 @@ class _WithSettings(object):
         return self.normalize(setting_name) in self._setters
 
     def normalize(self, setting):
-        result = utils.normalize(setting)
+        result = normalize(setting)
         return result[0:-1] if result and result[-1]==':' else result
 
 
@@ -402,7 +411,7 @@ class VariableTable(_Table):
         return OldStyleSettingAndVariableTableHeaderMatcher()
 
     def add(self, name, value, comment=None):
-        self.variables.append(Variable(name, value, comment))
+        self.variables.append(Variable(self, name, value, comment))
 
     def __iter__(self):
         return iter(self.variables)
@@ -454,12 +463,13 @@ class KeywordTable(_Table):
 
 class Variable(object):
 
-    def __init__(self, name, value, comment=None):
+    def __init__(self, parent, name, value, comment=None):
+        self.parent = parent
         self.name = name.rstrip('= ')
         if name.startswith('$') and value == []:
             value = ''
-        if isinstance(value, basestring):
-            value = [value]  # Must support scalar lists until RF 2.8 (issue 939)
+        if is_string(value):
+            value = [value]
         self.value = value
         self.comment = Comment(comment)
 
@@ -477,6 +487,13 @@ class Variable(object):
     def has_data(self):
         return bool(self.name or ''.join(self.value))
 
+    def __nonzero__(self):
+        return self.has_data()
+
+    def report_invalid_syntax(self, message, level='ERROR'):
+        self.parent.report_invalid_syntax("Setting variable '%s' failed: %s"
+                                          % (self.name, message), level)
+
 
 class _WithSteps(object):
 
@@ -556,6 +573,7 @@ class UserKeyword(TestCase):
         self.return_ = Return('[Return]', self)
         self.timeout = Timeout('[Timeout]', self)
         self.teardown = Fixture('[Teardown]', self)
+        self.tags = Tags('[Tags]', self)
         self.steps = []
 
     _setters = {'documentation': lambda s: s.doc.populate,
@@ -563,36 +581,49 @@ class UserKeyword(TestCase):
                 'arguments': lambda s: s.args.populate,
                 'return': lambda s: s.return_.populate,
                 'timeout': lambda s: s.timeout.populate,
-                'teardown': lambda s: s.teardown.populate}
+                'teardown': lambda s: s.teardown.populate,
+                'tags': lambda s: s.tags.populate}
 
     def _add_to_parent(self, test):
         self.parent.keywords.append(test)
 
     @property
     def settings(self):
-        return [self.args, self.doc, self.timeout, self.teardown, self.return_]
+        return [self.args, self.doc, self.tags, self.timeout, self.teardown, self.return_]
 
     def __iter__(self):
-        for element in [self.args, self.doc, self.timeout] \
+        for element in [self.args, self.doc, self.tags, self.timeout] \
                         + self.steps + [self.teardown, self.return_]:
             yield element
 
 
 class ForLoop(_WithSteps):
+    """The parsed representation of a for-loop.
+
+    :param list declaration: The literal cell values that declare the loop
+                             (excluding ":FOR").
+    :param str comment: A comment, default None.
+    :ivar str flavor: The value of the 'IN' item, uppercased.
+                      Typically 'IN', 'IN RANGE', 'IN ZIP', or 'IN ENUMERATE'.
+    :ivar list vars: Variables set per-iteration by this loop.
+    :ivar list items: Loop values that come after the 'IN' item.
+    :ivar str comment: A comment, or None.
+    :ivar list steps: A list of steps in the loop.
+    """
 
     def __init__(self, declaration, comment=None):
-        self.range, index = self._get_range_and_index(declaration)
+        self.flavor, index = self._get_flavors_and_index(declaration)
         self.vars = declaration[:index]
         self.items = declaration[index+1:]
         self.comment = Comment(comment)
         self.steps = []
 
-    def _get_range_and_index(self, declaration):
+    def _get_flavors_and_index(self, declaration):
         for index, item in enumerate(declaration):
-            item = item.upper().replace(' ', '')
-            if item in ['IN', 'INRANGE']:
-                return item == 'INRANGE', index
-        return False, len(declaration)
+            item = item.upper()
+            if item.replace(' ', '').startswith('IN'):
+                return item, index
+        return 'IN', len(declaration)
 
     def is_comment(self):
         return False
@@ -600,13 +631,9 @@ class ForLoop(_WithSteps):
     def is_for_loop(self):
         return True
 
-    def apply_template(self, template):
-        return self
-
     def as_list(self, indent=False, include_comment=True):
-        IN = ['IN RANGE' if self.range else 'IN']
         comments = self.comment.as_list() if include_comment else []
-        return  [': FOR'] + self.vars + IN + self.items + comments
+        return  [': FOR'] + self.vars + [self.flavor] + self.items + comments
 
     def __iter__(self):
         return iter(self.steps)
@@ -620,9 +647,9 @@ class Step(object):
     def __init__(self, content, comment=None):
         self.assign = list(self._get_assigned_vars(content))
         try:
-            self.keyword = content[len(self.assign)]
+            self.name = content[len(self.assign)]
         except IndexError:
-            self.keyword = None
+            self.name = None
         self.args = content[len(self.assign)+1:]
         self.comment = Comment(comment)
 
@@ -633,21 +660,16 @@ class Step(object):
             yield item
 
     def is_comment(self):
-        return not (self.assign or self.keyword or self.args)
+        return not (self.assign or self.name or self.args)
 
     def is_for_loop(self):
         return False
 
-    def apply_template(self, template):
-        if self.is_comment():
-            return self
-        return Step([template] + self.as_list(include_comment=False))
-
     def is_set(self):
         return True
 
     def as_list(self, indent=False, include_comment=True):
-        kw = [self.keyword] if self.keyword is not None else []
+        kw = [self.name] if self.name is not None else []
         comments = self.comment.as_list() if include_comment else []
         data = self.assign + kw + self.args + comments
         if indent:
